==> igniteui-react-16.16.2.tgz: package/esm2015/lib/NavDrawer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { NavDrawerPosition_$type } from "./NavDrawerPosition";
/**
 * @hidden
 */
export let NavDrawer = /*@__PURE__*/ (() => {
    class NavDrawer extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.e = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.b.d = this.e;
        }
        get a() {
            let ret_ = this.c.c("position");
            ret_ = enumGetBox(NavDrawerPosition_$type, EnumUtil.getEnumValue(NavDrawerPosition_$type, EnumUtil.parse(NavDrawerPosition_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(NavDrawerPosition_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(NavDrawerPosition_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.c.i("position", value_);
        }
        get d() {
            let ret_ = this.c.c("open");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.i("open", value_);
        }
        h() {
            this.nativeElement.show();
        }
        g() {
            this.nativeElement.hide();
        }
        i() {
            this.nativeElement.toggle();
        }
    }
    NavDrawer.$t = /*@__PURE__*/ markType(NavDrawer, 'NavDrawer', BaseElement.$);
    return NavDrawer;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/NavDrawer.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { NavDrawerPosition_$type } from "./NavDrawerPosition";
/**
 * @hidden
 */
export let NavDrawer = /*@__PURE__*/ (() => {
    class NavDrawer extends BaseElement {
        constructor() {
            super(...arguments);
            this.b = new WCNativeHelper();
            this.e = null;
        }
        get c() {
            return this.b;
        }
        get nativeElement() {
            return this.e;
        }
        set nativeElement(a) {
            this.e = a;
            this.b.o = this.e;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get a() {
            let ret_ = this.c.n("position");
            ret_ = enumGetBox(NavDrawerPosition_$type, EnumUtil.getEnumValue(NavDrawerPosition_$type, this.c.f(NavDrawerPosition_$type, ret_)));
            return EnumUtil.getEnumValue(NavDrawerPosition_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(NavDrawerPosition_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("position", value_);
        }
        get d() {
            let ret_ = this.c.n("open");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.c.v("open", value_);
        }
        i() {
            this.nativeElement.show();
        }
        g() {
            this.nativeElement.hide();
        }
        j() {
            this.nativeElement.toggle();
        }
    }
    NavDrawer.$t = /*@__PURE__*/ markType(NavDrawer, 'NavDrawer', BaseElement.$);
    return NavDrawer;
})();
